"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
const chalk_1 = require("chalk");
const inquirer = require("inquirer");
const path = require("path");
const semver = require("semver");
const convert_package_1 = require("../convert-package");
const manifest_converter_1 = require("../manifest-converter");
const util_1 = require("../util");
async function run(options) {
    const inDir = path.resolve(options.in || process.cwd());
    const outDir = path.resolve(options.out);
    // Ok, we're updating a package in a directory not under our control.
    // We need to be sure it's safe.
    const { stdout, stderr } = await util_1.exec(inDir, 'git', ['status', '-s']);
    if (!options.force && (stdout || stderr)) {
        console.error(`Git repo is dirty. Check all changes in to source control and ` +
            `then try again.`);
        process.exit(1);
    }
    // TODO: each file is not always needed, refactor to optimize loading
    let inBowerJson;
    let inPackageJson;
    let outPackageJson;
    try {
        outPackageJson = manifest_converter_1.readJson(outDir, 'package.json');
    }
    catch (e) {
        // do nothing
    }
    try {
        if (options.in) {
            inPackageJson = manifest_converter_1.readJson(inDir, 'package.json');
        }
    }
    catch (e) {
        // do nothing
    }
    try {
        inBowerJson = manifest_converter_1.readJson(inDir, 'bower.json');
    }
    catch (e) {
        // do nothing
    }
    let npmPackageName = options['npm-name'] ||
        inPackageJson && inPackageJson.name ||
        outPackageJson && outPackageJson.name;
    let npmPackageVersion = options['npm-version'] ||
        inPackageJson && inPackageJson.version ||
        outPackageJson && outPackageJson.version;
    // Prompt user for new package name & version if none exists
    // TODO(fks) 07-19-2017: Add option to suppress prompts
    if (typeof npmPackageName !== 'string') {
        npmPackageName = (await inquirer.prompt([{
                type: 'input',
                name: 'npm-name',
                message: 'npm package name?',
                default: inBowerJson && `@polymer/${inBowerJson.name}`,
            }]))['npm-name'];
    }
    if (typeof npmPackageVersion !== 'string') {
        npmPackageVersion =
            (await inquirer.prompt([{
                    type: 'input',
                    name: 'npm-version',
                    message: 'npm package version?',
                    default: inBowerJson && semver.inc(inBowerJson.version, 'major'),
                }]))['npm-version'];
    }
    console.log(chalk_1.default.dim('[1/2]') + ' 🌀  ' + chalk_1.default.magenta(`Converting Package...`));
    console.log(`Out directory: ${outDir}`);
    await convert_package_1.default({
        inDir: inDir,
        outDir: outDir,
        excludes: options.exclude,
        namespaces: options.namespace,
        npmImportStyle: options['import-style'],
        packageName: npmPackageName.toLowerCase(),
        packageVersion: npmPackageVersion,
        cleanOutDir: options.clean,
    });
    console.log(chalk_1.default.dim('[2/2]') + ' 🎉  ' + chalk_1.default.magenta(`Conversion Complete!`));
}
exports.default = run;
//# sourceMappingURL=command-package.js.map