"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ix_1 = require("ix");
const fs = require("mz/fs");
const path = require("path");
const _mkdirp = require("mkdirp");
const _rimraf = require("rimraf");
const { promisify } = require('util');
const { execFile: _execFile } = require('child_process');
const execFile = promisify(_execFile);
/**
 * Helper promisified "mkdirp" library function.
 */
exports.mkdirp = promisify(_mkdirp);
/**
 * Helper promisified "rimraf" library function.
 */
exports.rimraf = promisify(_rimraf);
/**
 * Write each file to the out-directory.
 */
async function writeFileResults(outDir, files) {
    return Promise.all(ix_1.Iterable.from(files).map(async ([newPath, newSource]) => {
        const filePath = path.join(outDir, newPath);
        await exports.mkdirp(path.dirname(filePath));
        if (newSource !== undefined) {
            await fs.writeFile(filePath, newSource);
        }
        else if (await fs.exists(filePath)) {
            await fs.unlink(filePath);
        }
    }));
}
exports.writeFileResults = writeFileResults;
/**
 * A helper function for working with Node's core execFile() method.
 */
async function exec(cwd, command, args, options) {
    const commandOptions = Object.assign({}, options, { cwd: cwd });
    try {
        const { stdout, stderr } = await execFile(command, args, commandOptions);
        // Trim unneccesary extra newlines/whitespace from exec/execFile output
        return { stdout: stdout.trim(), stderr: stderr.trim() };
    }
    catch (err) {
        // If an error happens, attach the working directory to the error object
        err.cwd = cwd;
        throw err;
    }
}
exports.exec = exec;
//# sourceMappingURL=util.js.map